@@ -15,11 +15,11 @@ Locale::Places - Translate places using http://download.geonames.org/
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 METHODS
 
@@ -57,10 +57,11 @@ sub new {
 =head2 translate
 
 Translate a city into a different language.
-Takes two mandatory arguments 'place'
-and 'from'.
-Takes an optional argument 'to'.
-If $to isn't given,
+Takes one mandatory argument: 'place'.
+It also takes two other arguments:
+'from' and 'to',
+at least one of which must be given.
+If neither $to nor $from is given,
 the code makes a best guess based on the environment.
 
    use Locale::Places;
@@ -86,16 +87,24 @@ sub translate {
 	if(!defined($place)) {
 		Carp::croak(__PACKAGE__, ': usage: translate(place => $place, from => $language1, to => $language2)');
 	}
+
+	my $to = $params{'to'};
 	my $from = $params{'from'};
-	if(!defined($from)) {
+	if((!defined($from)) && !defined($to)) {
 		Carp::croak(__PACKAGE__, ': usage: translate(place => $place, from => $language1, to => $language2)');
 	}
 
-	my $to = $params{'to'} || $self->_get_language();
+	$from ||= $self->_get_language();
+	if(!defined($from)) {
+		Carp::carp(__PACKAGE__, ": can't work out which language to translate from");
+		return;
+	}
+	$to ||= $self->_get_language();
 	if(!defined($to)) {
 		Carp::carp(__PACKAGE__, ": can't work out which language to translate to");
 		return;
 	}
+	return $place if($to eq $from);
 
 	# TODO: Add a country argument and choose a database based on that
 	$self->{'gb'} ||= Locale::Places::DB::GB->new(no_entry => 1);
@@ -173,7 +182,7 @@ L<http://deps.cpantesters.org/?module=Locale::Places>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright 2020 Nigel Horne.
+Copyright 2020-2021 Nigel Horne.
 
 This program is released under the following licence: GPL2
 
